@@ -9,9 +9,9 @@
  * Optional parameters:<pre>
  *   None.</pre>
  *
- * $Horde: gollem/lib/Auth/gollem.php,v 1.18.2.2 2005/11/27 18:41:52 slusarz Exp $
+ * $Horde: gollem/lib/Auth/gollem.php,v 1.18.2.4 2006/01/10 07:25:04 slusarz Exp $
  *
- * Copyright 2004-2005 Michael Slusarz <slusarz@curecanti.org>
+ * Copyright 2004-2006 Michael Slusarz <slusarz@curecanti.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -21,15 +21,6 @@
  */
 class Auth_gollem extends Auth {
 
-    /**
-     * Constructs a new Gollem authentication object.
-     *
-     * @param array $params  A hash containing connection parameters.
-     */
-    function Auth_gollem($params = array())
-    {
-    }
-
     /**
      * Find out if a set of login credentials are valid, and if
      * requested, mark the user as logged in in the current session.
