@@ -33,7 +33,7 @@ define('GOLLEM_SORT_DESCEND', 1);
 /**
  * Gollem Base Class.
  *
- * $Horde: gollem/lib/Gollem.php,v 1.172.2.14 2005/12/02 00:36:37 jan Exp $
+ * $Horde: gollem/lib/Gollem.php,v 1.172.2.18 2006/02/22 06:48:38 slusarz Exp $
  *
  * See the enclosed file COPYING for license information (GPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -96,6 +96,7 @@ class Gollem {
 
         return (((count($auto_server) == 1) || $force) &&
                 Auth::getAuth() &&
+                empty($GLOBALS['gollem_backends'][$key]['loginparams']) &&
                 !empty($GLOBALS['gollem_backends'][$key]['hordeauth']));
     }
 
@@ -756,6 +757,10 @@ class Gollem {
 
     /**
      * Build Gollem's list of menu items.
+     *
+     * @param string $returnType  Either 'object' or 'string'.
+     *
+     * @return mixed  Either a Horde_Menu object or the rendered menu text.
      */
     function getMenu($returnType = 'object')
     {
@@ -766,10 +771,10 @@ class Gollem {
 
         if (strpos($_SERVER['PHP_SELF'], 'manager.php') !== false) {
             if (Gollem::checkPermissions('backend', PERMS_EDIT)) {
-                $menu->add('', _("Create Folder"), 'mkdir.png', null, '', 'createFolder(); return false;');
+                $menu->add('#', _("Create Folder"), 'mkdir.png', null, '', 'createFolder(); return false;');
             }
             if (Gollem::checkPermissions('backend', PERMS_READ)) {
-                $menu->add('', _("Change Folder"), 'cd.png', null, '', 'changeDirectory(); return false;');
+                $menu->add('#', _("Change Folder"), 'cd.png', null, '', 'changeDirectory(); return false;');
             }
         }
 
@@ -777,7 +782,7 @@ class Gollem {
             if (Auth::isAdmin()) {
                 $menu->add(Util::addParameter(Horde::applicationUrl('permissions.php'), 'backend', $_SESSION['gollem']['backend_key']), _("Permissions"), 'administration.png', $GLOBALS['registry']->getImageDir('horde'));
             }
-    
+
             if ($_SESSION['gollem']['hasquota']) {
                 if ($GLOBALS['browser']->hasFeature('javascript')) {
                     Horde::addScriptFile('open_quota_win.js', 'gollem');
@@ -788,7 +793,7 @@ class Gollem {
                 $menu->add($quota_url, _("Check Quota"), 'info_icon.png', $GLOBALS['registry']->getImageDir('horde'));
             }
         }
- 
+
         if ($returnType == 'object') {
             return $menu;
         } else {
@@ -796,6 +801,37 @@ class Gollem {
         }
     }
 
+    /**
+     * Outputs Gollem's menu to the current output stream.
+     *
+     * @since Gollem 1.0.2
+     */
+    function menu()
+    {
+        require_once 'Horde/Template.php';
+        $t = &new Horde_Template();
+
+        $t->set('forminput', Util::formInput());
+        $t->set('be_select', Gollem::backendSelect(), true);
+        if ($t->get('be_select')) {
+        $t->set('accesskey', $GLOBALS['prefs']->getValue('widget_accesskey') ? Horde::getAccessKey(_("_Change Server")) : '');
+            $menu_view = $GLOBALS['prefs']->getValue('menu_view');
+            $link = Horde::link('#', _("Change Server"), '', '', 'serverSubmit(true);return false;');
+            $t->set('slink', sprintf('<ul><li>%s%s<br />%s</a></li></ul>', $link, ($menu_view != 'text') ? Horde::img('gollem.png') : '', ($menu_view != 'icon') ? Horde::highlightAccessKey(_("_Change Server"), $t->get('accesskey')) : ''));
+        }
+        $t->set('menu_string', Gollem::getMenu('string'));
+
+        echo $t->fetch(GOLLEM_TEMPLATES . '/menu.html');
+    }
+
+    /**
+     * Outputs Gollem's status/notification bar.
+     */
+    function status()
+    {
+        $GLOBALS['notification']->notify(array('listeners' => 'status'));
+    }
+
     /**
      * Generate the backend selection list for use in the menu.
      *
