@@ -5,7 +5,7 @@
  * This file defines Gollem's external API interface. Other
  * applications can interact with Gollem through this API.
  *
- * $Horde: gollem/lib/api.php,v 1.14.2.1 2005/11/11 23:04:27 jan Exp $
+ * $Horde: gollem/lib/api.php,v 1.14.2.2 2005/12/19 07:51:15 slusarz Exp $
  *
  * @author  Amith Varghese (amith@xalan.com)
  * @author  Michael Slusarz (slusarz@curecanti.org)
@@ -84,7 +84,7 @@ function _gollem_selectlistLink($link_text, $link_style, $formid,
     Horde::addScriptFile('open_selectlist_win.js', 'gollem');
     $link = Horde::link('#', $link_text, $link_style, '', 'open_selectlist_win(\'' . $formid . '\', \'' . $selectid . '\'); return false;');
     if ($icon) {
-        $link_text = Horde::img('gollem.png', $link_text, 'valign="middle"');
+        $link_text = Horde::img('gollem.png', $link_text, 'style="vertical-align:middle"');
     }
     return $link . $link_text . '</a>';
 }
