@@ -2,21 +2,27 @@
 /**
  * Login screen for Gollem.
  *
- * $Horde: gollem/login.php,v 1.94.2.5 2005/12/02 07:07:28 slusarz Exp $
+ * $Horde: gollem/login.php,v 1.94.2.12 2006/01/28 18:12:04 slusarz Exp $
  *
- * Copyright 1999-2005 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2005 Max Kalika <max@horde.org>
+ * Copyright 1999-2006 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2006 Max Kalika <max@horde.org>
  *
  * See the enclosed file COPYING for license information (GPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
  */
 
+function _notificationOutput(&$template)
+{
+    ob_start();
+    $GLOBALS['notification']->notify(array('listeners' => 'status'));
+    $template->set('notification_output', ob_get_contents());
+    ob_end_clean();
+}
+
 @define('AUTH_HANDLER', true);
 @define('GOLLEM_BASE', dirname(__FILE__));
 $authentication = 'none';
 require_once GOLLEM_BASE . '/lib/base.php';
-require_once 'Horde/Menu.php';
-require GOLLEM_BASE . '/config/credentials.php';
 
 /* Get an Auth object. */
 $gollem_auth = (Auth::getProvider() == 'gollem');
@@ -27,6 +33,7 @@ $autologin_fail = Util::getFormData('autologin_fail', false);
 $actionID = Util::getFormData('actionID');
 $backend_key = Util::getFormData('backend_key');
 $logout_reason = $auth->getLogoutReason();
+$url_param = Util::getFormData('url');
 
 /* Handle cases when we already have a session. */
 if (!empty($_SESSION['gollem']) && is_array($_SESSION['gollem'])) {
@@ -65,12 +72,10 @@ if (!empty($_SESSION['gollem']) && is_array($_SESSION['gollem'])) {
     } elseif (!$autologin_fail) {
         /* Check to see if we have logged in to the backend yet. */
         if (isset($_SESSION['gollem']['backends'][$backend_key])) {
-            if (Util::getFormData('change_backend')) {
-                require_once GOLLEM_BASE . '/lib/Session.php';
-                Gollem_Session::changeBackend($backend_key);
-            }
+            require_once GOLLEM_BASE . '/lib/Session.php';
+            Gollem_Session::changeBackend($backend_key);
 
-            $url = Util::getFormData('url');
+            $url = $url_param;
             if (empty($url)) {
                 /* If there is an existing session, redirect the user to the
                  * file manager. */
@@ -114,6 +119,9 @@ if (!empty($conf['auth']['alternate_login']) ||
     if (!isset($_COOKIE[session_name()])) {
         $url = Util::addParameter($url, session_name(), session_id());
     }
+    if ($url_param) {
+        $url = Util::addParameter($url, 'url', $url_param, false);
+    }
     header('Location: ' . $url);
     exit;
 }
@@ -124,6 +132,15 @@ Secret::setKey('gollem');
 if ($gollem_auth) {
     Secret::setKey('auth');
 }
+/* Prepare the login template. */
+require_once 'Horde/Template.php';
+$template = &new Horde_Template();
+$template->setOption('gettext', true);
+
+require_once 'Horde/Menu.php';
+$menu = &new Menu(HORDE_MENU_MASK_NONE);
+$template->set('menu', $menu->render(), true);
+$template->set('title', sprintf(_("%s Login"), $registry->get('name')));
 
 if (!$backend_key) {
     $backend_key = Gollem::getPreferredBackend();
@@ -132,7 +149,9 @@ if (!$backend_key) {
     if (is_null($backend_key)) {
         $reason = _("There are no backends available for the current user.");
         require GOLLEM_TEMPLATES . '/common-header.inc';
-        require GOLLEM_TEMPLATES . '/login/nologin.inc';
+        _notificationOutput($template);
+        $template->set('allowlogin', false, true);
+        echo $template->fetch(GOLLEM_TEMPLATES . '/login/login.html');
         if (@is_readable(GOLLEM_BASE . '/config/motd.php')) {
             require GOLLEM_BASE . '/config/motd.php';
         }
@@ -141,19 +160,6 @@ if (!$backend_key) {
     }
 }
 
-/* Build the <select> widget for the servers list. */
-if ($conf['backend']['backend_list'] == 'shown') {
-    $backends_list = '';
-
-    foreach ($GLOBALS['gollem_backends'] as $key => $curBackend) {
-        $sel = ($key == $backend_key) ? ' selected="selected"' : '';
-        $backends_list .= "<option value=\"$key\"$sel>";
-        $backends_list .= $curBackend['name'] . '</option>';
-    }
-
-    $autologin = Util::getFormData('autologin');
-}
-
 $login_vfs = array();
 foreach ($GLOBALS['gollem_backends'] as $key => $curBackend) {
     $login_vfs[$key] = &VFS::singleton($curBackend['driver'], array_merge($curBackend['params'], array('user' => Auth::getAuth())));
@@ -206,8 +212,98 @@ if (!Auth::getAuth() &&
     $ie_clientcaps = true;
 }
 
+$choose_language = ($gollem_auth && !$prefs->isLocked('language'));
+if ($choose_language) {
+    $lang_url = (!empty($url_param)) ? urlencode($url_param) : null;
+}
+
 require GOLLEM_TEMPLATES . '/common-header.inc';
-require GOLLEM_TEMPLATES . '/login/login.inc';
+require_once GOLLEM_TEMPLATES . '/login/javascript.inc';
+
+$tabindex = 0;
+$template->set('allowlogin', true, true);
+
+$template->set('action', Horde::url('redirect.php', false, -1, true));
+$template->set('gollem_auth', $gollem_auth, true);
+$template->set('form_input', Util::formInput());
+$template->set('actionid', $actionID);
+$template->set('load_frameset', ($gollem_auth) ? 1 : 0);
+$template->set('url', htmlspecialchars($url_param));
+$template->set('autologin', ($autologin || Gollem::canAutoLogin($backend_key, true)) ? 1 : 0);
+$template->set('clientcaps', !empty($ie_clientcaps), true);
+$template->set('backend_key', ($conf['backend']['backend_list'] != 'shown') ? $backend_key : null, true);
+
+_notificationOutput($template);
+
+$template->set('backend_shown', ($conf['backend']['backend_list'] == 'shown'), true);
+if ($template->get('backend_shown')) {
+    $template->set('shown_tabindex', ++$tabindex);
+    $shown_array = array();
+    foreach ($GLOBALS['gollem_backends'] as $key => $curBackend) {
+        $shown_array[] = array(
+            'sel' => ($key == $backend_key),
+            'name' => $curBackend['name'],
+            'val' => $key
+        );
+    }
+    $template->set('shown_array', $shown_array, true);
+}
+
+$template->set('backend_hidden', ($conf['backend']['backend_list'] == 'hidden'), true);
+if ($template->get('backend_hidden')) {
+    $template->set('hidden_text', sprintf(_("Connect to: %s"), $GLOBALS['gollem_backends'][$backend_key]['name']));
+}
+
+$loginparams = array();
+if (!empty($GLOBALS['gollem_backends'][$backend_key]['loginparams'])) {
+    foreach ($GLOBALS['gollem_backends'][$backend_key]['loginparams'] as $key => $val) {
+        $loginparams[] = array(
+            'label' => $val,
+            'tabindex' => ++$tabindex,
+            'name' => $key,
+            'val' => $GLOBALS['gollem_backends'][$backend_key]['params'][$key]
+        );
+    }
+}
+$template->set('loginparams', $loginparams);
+
+$log_creds = array();
+require GOLLEM_BASE . '/config/credentials.php';
+foreach ($login_vfs[$backend_key]->getRequiredCredentials() as $credential) {
+    if ((($credential == 'username') ||
+         ($credential == 'password')) &&
+        empty($GLOBALS['gollem_backends'][$backend_key]['hordeauth'])) {
+        $log_creds[] = array(
+            'label' => $credentials[$credential]['desc'],
+            'tabindex' => ++$tabindex,
+            'type' => $credentials[$credential]['type'],
+            'name' => $credential,
+            'val' => htmlspecialchars(Util::getFormData($credential))
+        );
+    }
+}
+$template->set('log_creds', $log_creds);
+
+$template->set('choose_language', $choose_language, true);
+if ($choose_language) {
+    $template->set('langs_tabindex', ++$tabindex);
+    $_SESSION['horde_language'] = NLS::select();
+    $langs = array();
+    foreach ($nls['languages'] as $key => $val) {
+        $langs[] = array(
+            'sel' => ($key == $_SESSION['horde_language']),
+            'val' => $key,
+            'name' => $val
+        );
+    }
+    $template->set('langs', $langs, true);
+}
+
+$template->set('login_tabindex', ++$tabindex);
+$template->set('login', _("Login"));
+
+echo $template->fetch(GOLLEM_TEMPLATES . '/login/login.html');
+
 if (@is_readable(GOLLEM_BASE . '/config/motd.php')) {
     require GOLLEM_BASE . '/config/motd.php';
 }
