@@ -1,9 +1,9 @@
 <?php
 /**
- * $Horde: gollem/manager.php,v 1.146.2.8 2005/12/04 21:21:54 chuck Exp $
+ * $Horde: gollem/manager.php,v 1.146.2.16 2006/03/14 07:18:43 slusarz Exp $
  *
- * Copyright 1999-2005 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2005 Max Kalika <max@horde.org>
+ * Copyright 1999-2006 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2006 Max Kalika <max@horde.org>
  *
  * See the enclosed file COPYING for license information (GPL).  If you
  * did notcan receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -107,7 +107,8 @@ case 'upload_file':
 
 case 'copy_items':
 case 'cut_items':
-    if (Gollem::checkPermissions('backend', PERMS_EDIT)) {
+    if (Gollem::checkPermissions('backend', PERMS_EDIT) &&
+        !empty($GLOBALS['gollem_be']['clipboard'])) {
         $action = ($actionID == 'copy_items') ? 'copy' : 'cut';
         $items = Util::getPost('items');
 
@@ -139,7 +140,8 @@ case 'cut_items':
 
 case 'clear_items':
 case 'paste_items':
-    if (Gollem::checkPermissions('backend', PERMS_EDIT)) {
+    if (Gollem::checkPermissions('backend', PERMS_EDIT) &&
+        !empty($GLOBALS['gollem_be']['clipboard'])) {
         $items = Util::getPost('items');
         if (is_array($items) && count($items)) {
             foreach ($items as $val) {
@@ -219,25 +221,81 @@ $view_url = Horde::applicationUrl('view.php');
 
 /* Get the list of copy/cut files in this directory. */
 $clipboard_files = array();
-foreach ($_SESSION['gollem']['clipboard'] as $val) {
-    if (($backkey == $val['backend']) && ($val['path'] == $currdir)) {
-        $clipboard_files[$val['name']] = 1;
+if (!empty($GLOBALS['gollem_be']['clipboard'])) {
+    foreach ($_SESSION['gollem']['clipboard'] as $val) {
+        if (($backkey == $val['backend']) && ($val['path'] == $currdir)) {
+            $clipboard_files[$val['name']] = 1;
+        }
     }
 }
 
 $title = $GLOBALS['gollem_be']['label'];
+Horde::addScriptFile('stripe.js', 'gollem', true);
 require GOLLEM_TEMPLATES . '/common-header.inc';
-require GOLLEM_TEMPLATES . '/menu.inc';
+Gollem::menu();
+Gollem::status();
 if ($browser->hasFeature('javascript')) {
-    require GOLLEM_TEMPLATES . '/manager/javascript.inc';
-    require $registry->get('templates', 'horde') . '/contents/open_view_win.js';
+    require_once GOLLEM_TEMPLATES . '/manager/javascript.inc';
+    require_once $registry->get('templates', 'horde') . '/contents/open_view_win.js';
 }
-require GOLLEM_TEMPLATES . '/manager/header.inc';
 
 /* Read the columns to display from the preferences. */
 $sources = Gollem::displayColumns();
 $columns = isset($sources[$backkey]) ? $sources[$backkey] : $GLOBALS['gollem_be']['attributes'];
 
+/* Prepare the template. */
+$template = &new Horde_Template();
+$template->setOption('gettext', true);
+
+$attrib = $GLOBALS['gollem_vfs']->getModifiablePermissions();
+foreach (array('owner', 'group', 'all') as $val) {
+    foreach (array('read', 'write', 'execute') as $val2) {
+        $template->set($val . '_' . $val2, !$attrib[$val][$val2], true);
+    }
+}
+
+$template->set('save', _("Save"));
+$template->set('cancel', _("Cancel"));
+$template->set('ok', _("OK"));
+
+$template->set('action', $manager_url);
+$template->set('forminput', Util::formInput());
+$template->set('dir', $currdir);
+$template->set('itemcount', (count($list) == 1) ? _("1 item") : sprintf(_("%d items"), count($list)));
+$template->set('navlink', Gollem::directoryNavLink($currdir, $manager_url));
+$template->set('refresh', Horde::link(Horde::selfUrl(), sprintf("%s %s", _("Refresh"), $GLOBALS['gollem_be']['label'])) . Horde::img('reload.png', sprintf("%s %s", _("Refresh"), htmlspecialchars($GLOBALS['gollem_be']['label'])), null, $registry->getImageDir('horde')) . '</a>');
+
+$edit_permissions = Gollem::checkPermissions('backend', PERMS_EDIT);
+$template->set('hasclipboard', !$edit_permissions || !empty($GLOBALS['gollem_be']['clipboard']), true);
+if (!$template->get('hasclipboard') ||
+    empty($_SESSION['gollem']['clipboard'])) {
+    $template->set('clipboard', null);
+} else {
+    $template->set('clipboard', Horde::link(Util::addParameter(Horde::applicationUrl('clipboard.php'), 'dir', $currdir), _("View Clipboard")) . Horde::img('clipboard.png', _("View Clipboard")) . '</a>');
+}
+
+if ($edit_permissions) {
+    $template->set('perms_edit', true, true);
+    $template->set('upload_file', _("Upload File(s)"));
+    $template->set('upload_help', Help::link('gollem', 'file-upload'));
+    $template->set('perms_chmod', in_array('permissions', $columns), true);
+} else {
+    $template->set('perms_edit', false, true);
+    $template->set('perms_chmod', false, true);
+}
+
+if (count($list)) {
+    $template->set('list_count', true, true);
+    if (Gollem::checkPermissions('backend', PERMS_DELETE)) {
+        $template->set('perms_delete', true, true);
+    } else {
+        $template->set('perms_edit', false, true);
+    }
+    $template->set('actions_help', Help::link('gollem', 'file-actions'));
+} else {
+    $template->set('list_count', false, true);
+}
+
 /* Set up column listing for cloop. */
 $columns_cloop = array();
 foreach ($columns as $val) {
@@ -250,18 +308,20 @@ if (is_array($list) &&
     count($list) &&
     Gollem::checkPermissions('backend', PERMS_READ)) {
     $entry = array();
-    $total_files = $total_folders = $total_size = 0;
+    $i = $total_files = $total_folders = $total_size = 0;
+
+    $template->set('empty_dir', false, true);
 
     foreach ($list as $key => $val) {
         $item = array();
 
         $item['date'] = strftime($conf['manager']['date_format'], $val['date']);
         $item['dl'] = false;
-        $item['group'] = $val['group'];
+        $item['group'] = (empty($val['group'])) ? '-' : $val['group'];
         $item['name'] = htmlspecialchars($val['name']);
         $item['on_clipboard'] = false;
-        $item['owner'] = $val['owner'];
-        $item['perms'] = $val['perms'];
+        $item['owner'] = (empty($val['owner'])) ? '-' : $val['owner'];
+        $item['perms'] = (empty($val['perms'])) ? '-' : $val['perms'];
         $item['size'] = ($val['type'] == '**dir') ? '-' : number_format($val['size'], 0, '.', ',');
         $item['type'] = $val['type'];
 
@@ -281,8 +341,8 @@ if (is_array($list) &&
             if (empty($icon_cache[$val['type']])) {
                 require_once 'Horde/MIME/Magic.php';
                 require_once 'Horde/MIME/Viewer.php';
-                require HORDE_BASE . '/config/mime_drivers.php';
-                require GOLLEM_BASE . '/config/mime_drivers.php';
+                require_once HORDE_BASE . '/config/mime_drivers.php';
+                require_once GOLLEM_BASE . '/config/mime_drivers.php';
                 $icon_cache[$val['type']] = Horde::img(MIME_Viewer::getIcon(MIME_Magic::extToMIME($val['type'])), '', '', '');
             }
             $item['graphic'] = $icon_cache[$val['type']];
@@ -359,7 +419,7 @@ if (is_array($list) &&
 
     $headers = array();
     foreach ($columns as $head) {
-        $hdr = array();
+        $hdr = array('class' => 'item', 'sort' => '');
         $sort = null;
 
         switch ($head) {
@@ -419,49 +479,24 @@ if (is_array($list) &&
         if (!is_null($sort)) {
             if ($sortby == $sort) {
                 $hdr['sort'] = '<a href="' . Util::addParameter($manager_url, array('actionID' => 'change_sortdir', 'sortdir' => abs(1 - $sortdir))) . '">' . Horde::img($sortdir ? 'za.png' : 'az.png', _("Sort Direction"), null, $registry->getImageDir('horde')) . '</a>&nbsp;';
-            } else {
-                $hdr['sort'] = '';
+                $hdr['class'] = 'selected';
             }
             $hdr['label'] = '<a href="' . Util::addParameter($manager_url, array('actionID' => 'change_sortby', 'sortby' => $sort)) .'">' . $hdr['label'] . '</a>';
-        } else {
-            $hdr['sort'] = '';
         }
 
         $headers[] = $hdr;
     }
 
     /* Set up the template tags. */
-    $template = &new Horde_Template();
     $template->set('headers', $headers, true);
     $template->set('entry', $entry, true);
     $template->setCloop('columns', $columns_cloop, $columns);
     $template->set('size_caption', $size_caption);
     $template->set('checkall', Horde::getAccessKeyAndTitle(_("Check _All/None")));
-    $template->set('type_class', '');
-    $template->set('name_class', '');
-    $template->set('date_class', '');
-    $template->set('size_class', '');
-    switch ($sortby) {
-    case GOLLEM_SORT_TYPE:
-        $template->set('type_class', ' class="linedRowSelectedCol"');
-        break;
 
-    case GOLLEM_SORT_NAME:
-        $template->set('name_class', ' class="linedRowSelectedCol"');
-        break;
-
-    case GOLLEM_SORT_DATE:
-        $template->set('date_class', ' class="linedRowSelectedCol"');
-        break;
-
-    case GOLLEM_SORT_SIZE:
-        $template->set('size_class', ' class="linedRowSelectedCol"');
-        break;
-    }
-
-    echo $template->fetch(GOLLEM_TEMPLATES . '/manager/manager.html');
 } else {
-    require GOLLEM_TEMPLATES . '/manager/empty_dir.inc';
+    $template->set('empty_dir', true, true);
 }
 
+echo $template->fetch(GOLLEM_TEMPLATES . '/manager/manager.html');
 require $registry->get('templates', 'horde') . '/common-footer.inc';
