@@ -1,9 +1,9 @@
 <?php
 /**
- * $Horde: gollem/redirect.php,v 1.55.2.4 2005/12/06 04:08:52 slusarz Exp $
+ * $Horde: gollem/redirect.php,v 1.55.2.6 2006/01/19 02:47:48 slusarz Exp $
  *
- * Copyright 1999-2005 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2005 Max Kalika <max@horde.org>
+ * Copyright 1999-2006 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2006 Max Kalika <max@horde.org>
  *
  * See the enclosed file COPYING for license information (GPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -16,9 +16,14 @@ require_once GOLLEM_BASE . '/lib/base.php';
 require GOLLEM_BASE . '/config/credentials.php';
 
 $actionID = Util::getFormData('actionID');
-$autologin = Util::getFormData('autologin');
 $backend_key = Util::getFormData('backend_key');
 
+if (is_null($backend_key)) {
+    $autologin = Util::getFormData('autologin', false);
+} else {
+    $autologin = Util::getFormData('autologin', Gollem::canAutoLogin($backend_key, true));
+}
+
 $user = (empty($autologin)) ? Util::getPost('username') : Gollem::getAutologinID($backend_key);
 $pass = (empty($autologin)) ? Util::getPost('password') : Auth::getCredential('password');
 
